@@ -25,6 +25,7 @@ from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import GObject
+import uaclient.api.u.pro.packages.updates.v1 as ua
 
 GdkX11  # pyflakes
 
@@ -39,9 +40,9 @@ import fnmatch
 import os
 import subprocess
 import sys
+import threading
 import time
 from gettext import gettext as _
-from uaclient.api.u.pro.packages.updates.v1 import updates
 
 import dbus
 import dbus.service
@@ -68,7 +69,7 @@ from .Core.AlertWatcher import AlertWatcher
 from .Core.MyCache import MyCache
 from .Core.roam import NetworkManagerHelper
 from .Core.UpdateList import UpdateList
-from .Core.utils import get_arch, get_dist
+from .Core.utils import get_arch, get_dist, SoftwarePropertiesPage
 from .backend import InstallBackend, get_backend
 
 # file that signals if we need to reboot
@@ -202,8 +203,9 @@ class UpdateManager(Gtk.Window):
         self._start_pane(None)
         sys.exit(0)
 
-    def show_settings(self):
-        cmd = ["/usr/bin/software-properties-gtk", "--open-tab", "2"]
+    def show_settings(self, page_number=SoftwarePropertiesPage.updates):
+        cmd = ["/usr/bin/software-properties-gtk",
+               "--open-tab", str(page_number)]
 
         if "WAYLAND_DISPLAY" not in os.environ:
             cmd += ["--toplevel", "%s" % self.get_window().get_xid()]
@@ -275,17 +277,37 @@ class UpdateManager(Gtk.Window):
             if fnmatch.fnmatch(pkg.name, "oem-*-meta") and pkg.installed:
                 self.oem_metapackages.add(pkg)
 
+    def _fetch_ua_updates(self):
+        self.ua_updates = ua.updates().updates
+
     def _get_ua_security_status(self):
         self.ua_security_packages = []
-        try:
-            update_result = updates()
-        except (IOError, OSError):
-            return
-        for info in update_result.updates:
-            if info.status == "pending_attach":
+        t = threading.Thread(target=self._fetch_ua_updates, daemon=True)
+        t.start()
+        while t.is_alive():
+            while Gtk.events_pending():
+                Gtk.main_iteration()
+            time.sleep(0.05)
+        for package in self.ua_updates:
+            if (
+                package.provided_by == 'standard-security'
+                or package.provided_by == 'standard-updates'
+            ):
+                continue
+            status = package.status
+            if (
+                status == 'pending_attach'
+                or status == 'pending_enable'
+                or status == 'upgrade_available'
+            ):
+                name = package.package
+                version = package.version
+                size = package.download_size
+                downloadable = status == 'upgrade_available'
                 self.ua_security_packages.append(
-                    (info.package, info.version, info.download_size)
+                    (name, version, size, downloadable)
                 )
+        self.cache.create_pro_cache(self.ua_security_packages)
 
     def _make_available_pane(
         self,
@@ -295,20 +317,7 @@ class UpdateManager(Gtk.Window):
         error_occurred=False,
     ):
         self._check_hwe_support_status()
-        if install_count == 0:
-            # Need Restart > New Release > No Updates
-            if need_reboot:
-                return NeedRestartDialog(self)
-            dist_upgrade = self._check_meta_release()
-            if dist_upgrade:
-                return dist_upgrade
-            elif cancelled_update:
-                return StoppedUpdatesDialog(self)
-            elif self.hwe_replacement_packages:
-                return HWEUpgradeDialog(self)
-            else:
-                return NoUpdatesDialog(self, error_occurred=error_occurred)
-        else:
+        if install_count != 0:
             header = None
             desc = None
             if error_occurred:
@@ -322,6 +331,19 @@ class UpdateManager(Gtk.Window):
             elif self.hwe_replacement_packages:
                 return HWEUpgradeDialog(self)
             return UpdatesAvailable(self, header, desc, need_reboot)
+        else:
+            # Need Restart > New Release > No Updates
+            if need_reboot:
+                return NeedRestartDialog(self)
+            dist_upgrade = self._check_meta_release()
+            if dist_upgrade:
+                return dist_upgrade
+            elif cancelled_update:
+                return StoppedUpdatesDialog(self)
+            elif self.hwe_replacement_packages:
+                return HWEUpgradeDialog(self)
+            else:
+                return NoUpdatesDialog(self, error_occurred=error_occurred)
 
     def start_error(self, update_and_retry, header, desc):
         if update_and_retry:
